@@ -9,15 +9,12 @@ mv benchmark/pabellon_barcelona/*.blend ~
 
 echo "#!/bin/bash
 
-[ ! -d /Volumes/Blender/ ] && hdid blender-2.92.0-macOS.dmg
+[ ! -d /Volumes/Blender/ ] && hdid blender-3.0.0-macos-x64.dmg
 
 BLEND_ARGS=\$@
 if [[ \$@ =~ .*CUDA.* ]]
 then
 	COMPUTE_TYPE=\"CUDA\"
-elif [[ \$@ =~ .*OPENCL.* ]]
-then
-	COMPUTE_TYPE=\"OPENCL\"
 elif [[ \$@ =~ .*OPTIX.* ]]
 then
 	COMPUTE_TYPE=\"OPTIX\"
