@@ -5,5 +5,6 @@ cd \"C:\Program Files\Indigo Benchmark\"
 ./Indigo\ Benchmark.exe \$@ > \$LOG_FILE" > indigobench
 chmod +x indigobench
 
-chmod +x IndigoBenchmark_v4.4.15_Setup.exe
-/cygdrive/c/Windows/system32/cmd.exe /c IndigoBenchmark_v4.4.15_Setup.exe
+chmod +x IndigoBenchmark_x64_v4.0.64_Setup.exe
+/cygdrive/c/Windows/system32/cmd.exe /c IndigoBenchmark_x64_v4.0.64_Setup.exe
+
