@@ -1,20 +1,20 @@
 #!/bin/sh
 
-tar -xf libjxl-0.5.tar.gz
+tar -xf jpeg-xl-v0.3.3.tar.gz
 tar -xf png-samples-1.tar.xz
 unzip -o sample-photo-6000x4000-1.zip
 
-cd libjxl-0.5
+cd jpeg-xl-v0.3.3/
 ./deps.sh
 mkdir build
 cd build
 cmake .. -DCMAKE_BUILD_TYPE=Release -DBUILD_TESTING=OFF
-cmake --build . -- -j $NUM_CPU_CORES
+make -j $NUM_CPU_CORES
 echo $? > ~/install-exit-status
 
 cd ~
 
 echo "#!/bin/sh
-./libjxl-0.5/build/tools/cjxl \$@ > \$LOG_FILE 2>&1
+./jpeg-xl-v0.3.3/build/tools/cjxl \$@ > \$LOG_FILE 2>&1
 echo \$? > ~/test-exit-status" > jpegxl
 chmod +x jpegxl
