@@ -1,13 +1,13 @@
 #!/bin/sh
 
-version=7.2
+version=7.7
 tar xvf primesieve-$version.tar.gz
 cd primesieve-$version
 
 cmake . -DBUILD_SHARED_LIBS=OFF
-make -j $NUM_CPU_JOBS
+make -j $NUM_CPU_CORES
 echo $? > ~/install-exit-status
-cd ..
+cd ~
 
 echo "#!/bin/sh
 primesieve-$version/./primesieve \$@ > \$LOG_FILE 2>&1
