@@ -1,17 +1,17 @@
 #!/bin/sh
 
-tar -xzf redis-6.0.9.tar.gz
+tar -xzf redis-3.0.1.tar.gz
 
-cd ~/redis-6.0.9/deps
+cd ~/redis-3.0.1/deps
 make hiredis jemalloc linenoise lua
 
-cd ~/redis-6.0.9
-make MALLOC=libc -j $NUM_CPU_CORES
+cd ~/redis-3.0.1
+make -j $NUM_CPU_JOBS
 echo $? > ~/install-exit-status
 
 cd ~
 echo "#!/bin/sh
-cd ~/redis-6.0.9
+cd ~/redis-3.0.1/
 
 ./src/redis-server &
 REDIS_SERVER_PID=\$!
