@@ -2,7 +2,7 @@
 
 rm -rf Xonotic_
 
-unzip -o xonotic-0.8.0.zip
+unzip -o xonotic-0.8.2.zip
 mv Xonotic Xonotic_
 
 echo "#!/bin/sh
@@ -11,6 +11,6 @@ if [ \$OS_TYPE = \"MacOSX\" ]
 then
 	./Xonotic.app/Contents/MacOS/xonotic-osx-sdl \$@ > \$LOG_FILE 2>&1
 else
-	./xonotic-linux-sdl.sh \$@ > \$LOG_FILE 2>&1
+	./xonotic-linux64-sdl \$@ > \$LOG_FILE 2>&1
 fi" > xonotic
 chmod +x xonotic
