@@ -1,9 +1,9 @@
 #!/bin/sh
-unzip -o selenium-scripts-6.zip
+unzip -o selenium-scripts-9.zip
 
 # Drivers
-unzip -o geckodriver-v0.24.0-win64.zip
-unzip -o chromedriver_win32.zip
+unzip -o geckodriver-v0.26.0-win64.zip
+unzip -o chromedriver_win32_v86.zip
 
 # Script
 echo "#!/bin/sh
