@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2013, Phoronix Media
-	Copyright (C) 2009 - 2013, Michael Larabel
+	Copyright (C) 2009 - 2018, Phoronix Media
+	Copyright (C) 2009 - 2018, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -20,26 +20,14 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-class gpu_freq implements phodevi_sensor
+//TODO refactor and fix returning of two values
+class gpu_freq extends phodevi_sensor
 {
-	public static function get_type()
-	{
-		return 'gpu';
-	}
-	public static function get_sensor()
-	{
-		return 'freq';
-	}
-	public static function get_unit()
-	{
-		return 'Megahertz';
-	}
-	public static function support_check()
-	{
-		$test = self::read_sensor();
-		return is_numeric($test) && $test > 0;
-	}
-	public static function read_sensor()
+	const SENSOR_TYPE = 'gpu';
+	const SENSOR_SENSES = 'freq';
+	const SENSOR_UNIT = 'Megahertz';
+
+	public function read_sensor()
 	{
 		// Graphics processor real/current frequency
 		$show_memory = false;
@@ -54,19 +42,39 @@ class gpu_freq implements phodevi_sensor
 			$core_freq = isset($nv_freq[0]) ? $nv_freq[0] : 0;
 			$mem_freq = isset($nv_freq[1]) ? $nv_freq[1] : 0;
 		}
-		else if(phodevi::is_ati_graphics() && phodevi::is_linux()) // ATI GPU
-		{
-			$od_clocks = phodevi_linux_parser::read_ati_overdrive('CurrentClocks');
-
-			if(is_array($od_clocks) && count($od_clocks) >= 2) // ATI OverDrive
-			{
-				$core_freq = array_shift($od_clocks);
-				$mem_freq = array_pop($od_clocks);
-			}
-		}
 		else if(phodevi::is_linux())
 		{
-			if(isset(phodevi::$vfs->radeon_pm_info))
+			if(is_readable('/sys/class/drm/card0/device/pp_dpm_sclk'))
+			{
+				$pp = PHP_EOL . file_get_contents('/sys/class/drm/card0/device/pp_dpm_sclk');
+				$pp = substr($pp, 0, strpos($pp, '*'));
+				$pp = substr($pp, strrpos($pp, PHP_EOL));
+				if(($x = strpos($pp, ': ')) !== false)
+				{
+					$pp = substr($pp, $x + 2);
+				}
+				$pp = trim(str_replace(array('*', 'Mhz'), '', $pp));
+				if(is_numeric($pp))
+				{
+					$core_freq = $pp;
+					if(is_readable('/sys/class/drm/card0/device/pp_dpm_mclk'))
+					{
+						$pp = PHP_EOL . file_get_contents('/sys/class/drm/card0/device/pp_dpm_mclk');
+						$pp = substr($pp, 0, strpos($pp, '*'));
+						$pp = substr($pp, strrpos($pp, PHP_EOL));
+						if(($x = strpos($pp, ': ')) !== false)
+						{
+							$pp = substr($pp, $x + 2);
+						}
+						$pp = trim(str_replace(array('*', 'Mhz'), '', $pp));
+						if(is_numeric($pp))
+						{
+							$mem_freq = $pp;
+						}
+					}
+				}
+			}
+			else if(isset(phodevi::$vfs->radeon_pm_info))
 			{
 				// radeon_pm_info should be present with Linux 2.6.34+
 				foreach(pts_strings::trim_explode("\n", phodevi::$vfs->radeon_pm_info) as $pm_line)
@@ -140,7 +148,7 @@ class gpu_freq implements phodevi_sensor
 				$core_string = array_search('core', $performance_level);
 				if($core_string !== false && isset($performance_level[($core_string + 1)]))
 				{
-					$core_string = str_ireplace('MHz', null, $performance_level[($core_string + 1)]);
+					$core_string = str_ireplace('MHz', '', $performance_level[($core_string + 1)]);
 					if(is_numeric($core_string) && $core_string > $core_freq)
 					{
 						$core_freq = $core_string;
@@ -150,7 +158,7 @@ class gpu_freq implements phodevi_sensor
 				$mem_string = array_search('memory', $performance_level);
 				if($mem_string !== false && isset($performance_level[($mem_string + 1)]))
 				{
-					$mem_string = str_ireplace('MHz', null, $performance_level[($mem_string + 1)]);
+					$mem_string = str_ireplace('MHz', '', $performance_level[($mem_string + 1)]);
 					if(is_numeric($mem_string) && $mem_string > $mem_freq)
 					{
 						$mem_freq = $mem_string;
