@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2021, Phoronix Media
-	Copyright (C) 2008 - 2021, Michael Larabel
+	Copyright (C) 2008 - 2022, Phoronix Media
+	Copyright (C) 2008 - 2022, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@ class pts_result_file
 {
 	protected $save_identifier = null;
 	protected $result_objects = null;
-	protected $extra_attributes = null;
 	protected $is_multi_way_inverted = false;
 	protected $file_location = false;
 
@@ -42,7 +41,6 @@ class pts_result_file
 	public function __construct($result_file = null, $read_only_result_objects = false, $parse_only_qualified_result_objects = false)
 	{
 		$this->save_identifier = $result_file;
-		$this->extra_attributes = array();
 		$this->systems = array();
 		$this->result_objects = array();
 		$this->ro_relation_map = array();
@@ -71,14 +69,14 @@ class pts_result_file
 			$this->internal_tags = self::clean_input($xml->Generated->InternalTags);
 			$this->reference_id = self::clean_input($xml->Generated->ReferenceID);
 			$this->preset_environment_variables = self::clean_input($xml->Generated->PreSetEnvironmentVariables);
-			$this->last_modified = $xml->Generated->LastModified;
+			$this->last_modified = self::clean_input($xml->Generated->LastModified);
 		}
 
 		if(isset($xml->System))
 		{
 			foreach($xml->System as $s)
 			{
-				$this->systems[] = new pts_result_file_system(self::clean_input($s->Identifier->__toString()), self::clean_input($s->Hardware->__toString()), self::clean_input($s->Software->__toString()), json_decode(self::clean_input($s->JSON), true), self::clean_input($s->User->__toString()), self::clean_input($s->Notes->__toString()), self::clean_input($s->TimeStamp->__toString()), self::clean_input($s->ClientVersion->__toString()), $this);
+				$this->systems[] = new pts_result_file_system(self::clean_input($s->Identifier->__toString()), self::clean_input($s->Hardware->__toString()), self::clean_input($s->Software->__toString()), json_decode(self::clean_input($s->JSON), true), self::clean_input($s->User->__toString()), self::clean_input($s->Notes->__toString()), self::clean_input($s->TimeStamp->__toString()), self::clean_input($s->TestClientVersion->__toString()), $this);
 			}
 		}
 
@@ -183,7 +181,7 @@ class pts_result_file
 	}
 	public function get_test_log_dir(&$result_object = null)
 	{
-		$log_dir = dirname($this->get_file_location());
+		$log_dir = $this->get_file_location() != null ? dirname($this->get_file_location()) : '';
 		if(empty($log_dir) || !is_dir($log_dir))
 		{
 			return false;
@@ -236,22 +234,10 @@ class pts_result_file
 		}
 		*/
 	}
-	public function default_result_folder_path()
-	{
-		return PTS_SAVE_RESULTS_PATH . $this->save_identifier . '/';
-	}
 	public function get_identifier()
 	{
 		return $this->save_identifier;
 	}
-	public function read_extra_attribute($key)
-	{
-		return isset($this->extra_attributes[$key]) ? $this->extra_attributes[$key] : false;
-	}
-	public function set_extra_attribute($key, $value)
-	{
-		$this->extra_attributes[$key] = $value;
-	}
 	public function add_system($system)
 	{
 		if(!in_array($system, $this->systems))
@@ -259,10 +245,6 @@ class pts_result_file
 			$this->systems[] = $system;
 		}
 	}
-	public function add_system_direct($identifier, $hw = null, $sw = null, $json = null, $user = null, $notes = null, $timestamp = null, $version = null)
-	{
-		$this->systems[] = new pts_result_file_system($identifier, $hw, $sw, $json, $user, $notes, $timestamp, $version, $this);
-	}
 	public function get_systems()
 	{
 		return $this->systems;
@@ -297,6 +279,16 @@ class pts_result_file
 		}
 		return $ids;
 	}
+	public function get_system_identifiers_by_date()
+	{
+		$by_date = array();
+		foreach($this->get_systems() as $s)
+		{
+			$by_date[$s->get_identifier()] = strtotime($s->get_timestamp());
+		}
+		asort($by_date);
+		return array_keys($by_date);
+	}
 	public function is_system_identifier_in_result_file($identifier)
 	{
 		foreach($this->systems as &$s)
@@ -309,6 +301,64 @@ class pts_result_file
 
 		return false;
 	}
+	public function system_logs_available()
+	{
+		$has_system_logs = false;
+		$system_log_dir_or_zip = is_dir($this->get_system_log_dir(null, true)) || is_file($this->get_result_dir() . 'system-logs.zip');
+
+		if($system_log_dir_or_zip)
+		{
+			if($this->get_system_count() == 1)
+			{
+				// If just one system in result file and there is a log, safe to assume it's for the associated run...
+				$has_system_logs = true;
+			}
+			else
+			{
+				foreach($this->systems as &$s)
+				{
+					if($s->has_log_files())
+					{
+						$has_system_logs = true;
+						break;
+					}
+				}
+			}
+		}
+
+		return $has_system_logs;
+	}
+	public function identifiers_with_system_logs()
+	{
+		$identifiers = array();
+		$system_log_dir = $this->get_system_log_dir(null, true);
+		if($system_log_dir && is_dir($system_log_dir))
+		{
+			foreach(pts_file_io::glob($system_log_dir . '/*') as $identifier_dir)
+			{
+				$identifiers[] = basename($identifier_dir);
+			}
+		}
+		else if($this->get_result_dir() && is_file($this->get_result_dir() . 'system-logs.zip'))
+		{
+			$zip = new ZipArchive();
+			$res = $zip->open($this->get_result_dir() . 'system-logs.zip');
+
+			if($res === true)
+			{
+				for($i = 0; $i < $zip->numFiles; $i++)
+				{
+					$index = explode('/', $zip->getNameIndex($i));
+					if(!empty($index[1]) && !in_array($index[1], $identifiers))
+					{
+						$identifiers[] = $index[1];
+					}
+				}
+				$zip->close();
+			}
+		}
+		return $identifiers;
+	}
 	public function get_system_count()
 	{
 		return count($this->systems);
@@ -411,7 +461,7 @@ class pts_result_file
 		{
 			if($hash_to_check == $result_object->get_comparison_hash())
 			{
-				if(in_array($run_identifier_to_check, $result_object->test_result_buffer->get_identifiers()))
+				if(in_array($run_identifier_to_check, $result_object->test_result_buffer->get_identifiers()) && $result_object->test_result_buffer->get_result_from_identifier($run_identifier_to_check) != '')
 				{
 					$found_match = true;
 				}
@@ -518,10 +568,6 @@ class pts_result_file
 
 		return $is_multi_way;
 	}
-	public function invert_multi_way_invert()
-	{
-		$this->is_multi_way_inverted = !$this->is_multi_way_inverted;
-	}
 	public function is_multi_way_inverted()
 	{
 		return $this->is_multi_way_inverted;
@@ -563,7 +609,7 @@ class pts_result_file
 				{
 					foreach($this->get_relation_map($index) as $child_ro)
 					{
-						if($this->result_objects[$child_ro])
+						if(isset($this->result_objects[$child_ro]))
 						{
 							unset($this->result_objects[$child_ro]);
 						}
@@ -688,11 +734,13 @@ class pts_result_file
 	}
 	public function rename_run($from, $to, $rename_logs = true)
 	{
+		$renamed = false;
 		if($from == 'PREFIX')
 		{
 			foreach($this->systems as &$s)
 			{
 				$s->set_identifier($to . ': ' . $s->get_identifier());
+				$renamed = true;
 			}
 		}
 		else if($from == null)
@@ -702,6 +750,7 @@ class pts_result_file
 				foreach($this->systems as &$s)
 				{
 					$s->set_identifier($to);
+					$renamed = true;
 					break;
 				}
 			}
@@ -715,16 +764,19 @@ class pts_result_file
 				{
 					$found = true;
 					$s->set_identifier($to);
+					$renamed = true;
 					break;
 				}
 			}
-			if($found && $rename_logs && PTS_IS_CLIENT && defined(PTS_SAVE_RESULTS_PATH) && is_dir(($dir_base = PTS_SAVE_RESULTS_PATH . $this->get_identifier() . '/')))
+			if($found && $rename_logs && ($d = $this->get_system_log_dir($from, true)))
 			{
+				$d = dirname(dirname($d)) . '/';
+
 				foreach(array('test-logs', 'system-logs', 'installation-logs') as $dir_name)
 				{
-					if(is_dir($dir_base . $dir_name . '/' . $rename_identifier))
+					if(is_dir($d . $dir_name . '/' . $from))
 					{
-						rename($dir_base . $dir_name . '/' . $rename_identifier, $dir_base . $dir_name . '/' . $rename_identifier_new);
+						rename($d . $dir_name . '/' . $from, $d . $dir_name . '/' . $to);
 					}
 				}
 			}
@@ -734,6 +786,8 @@ class pts_result_file
 		{
 			$result->test_result_buffer->rename($from, $to);
 		}
+
+		return $renamed;
 	}
 	public function reorder_runs($new_order)
 	{
@@ -758,12 +812,14 @@ class pts_result_file
 	}
 	public function remove_run($remove)
 	{
+		$did_remove = false;
 		$remove = pts_arrays::to_array($remove);
 		foreach($this->systems as $i => &$s)
 		{
 			if(in_array($s->get_identifier(), $remove))
 			{
 				unset($this->systems[$i]);
+				$did_remove = true;
 			}
 		}
 
@@ -771,6 +827,7 @@ class pts_result_file
 		{
 			$result->test_result_buffer->remove($remove);
 		}
+		return $did_remove;
 	}
 	public function add_to_result_file(&$result_file, $only_merge_results_already_present = false)
 	{
@@ -843,7 +900,7 @@ class pts_result_file
 		$xml_writer = new nye_XmlWriter(null, $force_nice_formatting);
 		$xml_writer->addXmlNode('PhoronixTestSuite/Generated/Title', $this->get_title());
 		$xml_writer->addXmlNode('PhoronixTestSuite/Generated/LastModified', date('Y-m-d H:i:s', pts_client::current_time()));
-		$xml_writer->addXmlNode('PhoronixTestSuite/Generated/TestClient', pts_core::program_title(true));
+		$xml_writer->addXmlNode('PhoronixTestSuite/Generated/TestClient', pts_core::program_title());
 		$xml_writer->addXmlNode('PhoronixTestSuite/Generated/Description', $this->get_description());
 		$xml_writer->addXmlNodeWNE('PhoronixTestSuite/Generated/Notes', $this->get_notes());
 		$xml_writer->addXmlNodeWNE('PhoronixTestSuite/Generated/InternalTags', $this->get_internal_tags());
@@ -914,41 +971,19 @@ class pts_result_file
 			return false;
 		}
 
-		foreach($result_merges_to_combine as $i => &$merge_select)
+		foreach($result_merges_to_combine as &$result_file)
 		{
-			if(!($merge_select instanceof $merge_select))
+			if(!($result_file instanceof pts_result_file))
 			{
-				$merge_select = new pts_result_merge_select($merge_select);
-			}
-
-			if(!is_file($merge_select->get_result_file()) && !($merge_select->get_result_file() instanceof pts_result_file))
-			{
-				if(defined('PTS_SAVE_RESULTS_PATH') && is_file(PTS_SAVE_RESULTS_PATH . $merge_select->get_result_file() . '/composite.xml'))
+				if(defined('PTS_SAVE_RESULTS_PATH') && is_file(PTS_SAVE_RESULTS_PATH . $result_file . '/composite.xml'))
 				{
-					$merge_select->set_result_file(PTS_SAVE_RESULTS_PATH . $merge_select->get_result_file() . '/composite.xml');
+					$result_file = new pts_result_file(PTS_SAVE_RESULTS_PATH . $result_file . '/composite.xml', true);
 				}
 				else
 				{
-					unset($result_merges_to_combine[$i]);
+					continue;
 				}
 			}
-		}
-
-		if(empty($result_merges_to_combine))
-		{
-			return false;
-		}
-
-		foreach($result_merges_to_combine as &$merge_select)
-		{
-			if($merge_select->get_result_file() instanceof pts_result_file)
-			{
-				$result_file = $merge_select->get_result_file();
-			}
-			else
-			{
-				$result_file = new pts_result_file($merge_select->get_result_file(), true);
-			}
 
 			if($add_prefix)
 			{
@@ -968,10 +1003,6 @@ class pts_result_file
 					$result_file->rename_run('PREFIX', $add_prefix);
 				}
 			}
-			else if($merge_select->get_rename_identifier())
-			{
-				$result_file->rename_run(null, $merge_select->get_rename_identifier());
-			}
 
 			if($this->get_title() == null && $result_file->get_title() != null)
 			{
@@ -1082,7 +1113,10 @@ class pts_result_file
 		{
 			foreach($ro->get_run_times() as $si => $elapsed_time)
 			{
-				$run_times[$si] += $elapsed_time;
+				if(isset($run_times[$si]) && $elapsed_time > 0)
+				{
+					$run_times[$si] += $elapsed_time;
+				}
 			}
 		}
 
@@ -1109,6 +1143,162 @@ class pts_result_file
 
 		return $a < $b ? -1 : 1;
 	}
+	public function get_install_log_for_test(&$test_profile, $read_file = false, $cleanse_file = true)
+	{
+		// if $read_file is false, index will be returned. if $read_file is -2, will return whether log files simply exist
+		$files = array();
+		static $logs_exist_for_test; // caching helper
+		$test_file_name_chunk = $test_profile->get_identifier_simplified() . '.log';
+
+		if($read_file == -2 && isset($logs_exist_for_test[$test_file_name_chunk]))
+		{
+			return $logs_exist_for_test[$test_file_name_chunk];
+		}
+
+		if($this->get_test_installation_log_dir() && count($d = pts_file_io::glob($this->get_test_installation_log_dir() . '*/' . $test_file_name_chunk)) > 0)
+		{
+			$logs_exist_for_test[$test_file_name_chunk] = true;
+			if($read_file == -2)
+			{
+				return true;
+			}
+
+			foreach($d as $file)
+			{
+				$basename_file = basename(dirname($file));
+				if($read_file !== false && $basename_file == $read_file)
+				{
+					$file = file_get_contents($file);
+					return $cleanse_file ? phodevi_vfs::cleanse_file($file, $basename_file) : $file;
+				}
+				$files[] = $basename_file;
+			}
+		}
+		else if($this->get_result_dir() && is_file($this->get_result_dir() . 'installation-logs.zip') && extension_loaded('zip'))
+		{
+			$logs_exist_for_test[$test_file_name_chunk] = true;
+			if($read_file == -2)
+			{
+				// TODO: could make this more accurate to ensure a precise match, but could become expensive
+				return true;
+			}
+
+			$zip = new ZipArchive();
+			$res = $zip->open($this->get_result_dir() . 'installation-logs.zip');
+
+			if($res === true)
+			{
+				$search_for_file_name_length = strlen($test_file_name_chunk);
+				for($i = 0; $i < $zip->numFiles; $i++)
+				{
+					$index = $zip->getNameIndex($i);
+					if(isset($index[$search_for_file_name_length]) && substr($index, (0 - $search_for_file_name_length)) == $test_file_name_chunk)
+					{
+						$basename_file = basename(dirname($index));
+
+						if($basename_file != null)
+						{
+							if($read_file !== false && $basename_file == $read_file)
+							{
+								$c = $zip->getFromName($index);
+								$contents = $cleanse_file ? phodevi_vfs::cleanse_file($c, $basename_file) : $c;
+								$zip->close();
+								return $contents;
+							}
+							$files[] = $basename_file;
+						}
+					}
+				}
+				$zip->close();
+			}
+		}
+
+		$logs_exist_for_test[$test_file_name_chunk] = !empty($files);
+		if($read_file == -2)
+		{
+			return false;
+		}
+
+		return $read_file !== false ? false : $files;
+	}
+	public function get_test_run_log_for_result(&$result_object, $read_file = false, $cleanse_file = true)
+	{
+		// if $read_file is false, index will be returned. if $read_file is -2, will return whether log files simply exist
+		$files = array();
+		static $logs_exist_for_test; // caching helper
+		$ro_hash = $result_object->get_comparison_hash(true, false);
+
+		if($read_file == -2 && isset($logs_exist_for_test[$ro_hash]))
+		{
+			return $logs_exist_for_test[$ro_hash];
+		}
+
+		if(($test_log_dir = $this->get_test_log_dir($result_object)) && count($d = pts_file_io::glob($test_log_dir . '*.log')) > 0)
+		{
+			$logs_exist_for_test[$ro_hash] = true;
+			if($read_file == -2)
+			{
+				return true;
+			}
+
+			foreach($d as $file)
+			{
+				$basename_file = basename($file);
+				if($read_file !== false && $basename_file == $read_file)
+				{
+					$file = file_get_contents($file);
+					return $cleanse_file ? phodevi_vfs::cleanse_file($file, $basename_file) : $file;
+				}
+				$files[] = $basename_file;
+			}
+		}
+		else if($this->get_result_dir() && is_file($this->get_result_dir() . 'test-logs.zip') && extension_loaded('zip'))
+		{
+			$logs_exist_for_test[$ro_hash] = true;
+			if($read_file == -2)
+			{
+				// TODO: could make this more accurate to ensure a precise match, but could become expensive
+				return true;
+			}
+
+			$zip = new ZipArchive();
+			$res = $zip->open($this->get_result_dir() . 'test-logs.zip');
+
+			if($res === true)
+			{
+				$log_path = 'test-logs/' . $ro_hash . '/';
+				$log_path_l = strlen($log_path);
+				for($i = 0; $i < $zip->numFiles; $i++)
+				{
+					$index = $zip->getNameIndex($i);
+					if(isset($index[$log_path_l]) && substr($index, 0, $log_path_l) == $log_path)
+					{
+						$basename_file = substr($index, $log_path_l);
+						if($basename_file != null)
+						{
+							if($read_file !== false && $basename_file == $read_file)
+							{
+								$c = $zip->getFromName($index);
+								$contents = $cleanse_file ? phodevi_vfs::cleanse_file($c, $basename_file) : $c;
+								$zip->close();
+								return $contents;
+							}
+							$files[] = $basename_file;
+						}
+					}
+				}
+				$zip->close();
+			}
+		}
+
+		$logs_exist_for_test[$ro_hash] = !empty($files);
+		if($read_file == -2)
+		{
+			return false;
+		}
+
+		return $read_file !== false ? false : $files;
+	}
 }
 
 ?>
